@@ -1,5 +1,5 @@
 /*
- * smartcalc v1.0.2
+ * smartcalc v1.0.5
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
@@ -19,7 +19,8 @@ use crate::token::ui_token::{UiToken, UiTokenCollection};
 use crate::tokinizer::TokenInfo;
 use crate::tokinizer::TokenInfoStatus;
 use crate::tokinizer::Tokinizer;
-use crate::types::TokenType;
+use crate::tools::parse_timezone;
+use crate::types::{TokenType, NumberType};
 use crate::types::{SmartCalcAstType, VariableInfo};
 use crate::formatter::format_result;
 use crate::worker::tools::read_currency;
@@ -196,10 +197,21 @@ impl SmartCalc {
     }
     
     pub fn set_timezone(&mut self, timezone: String) -> Result<(), String> {
-        match self.config.timezones.get(&timezone.to_uppercase()) {
-            Some(offset) => {
+        let timezone = match self.config.token_parse_regex.get("timezone") {
+            Some(regexes) => {
+                let capture = regexes[0].captures(&timezone).unwrap();
+                match capture.name("timezone") {
+                    Some(_) => parse_timezone(&self.config, &capture),
+                    None => None
+                }
+            },
+            _ => None
+        };
+        
+        match timezone {
+            Some((timezone, offset)) => {
                 self.config.timezone = timezone.to_uppercase();
-                self.config.timezone_offset = *offset;
+                self.config.timezone_offset = offset;
                 Ok(())
             },
             None => Err("Timezone information not found".to_string())
@@ -273,7 +285,7 @@ impl SmartCalc {
         let mut operator_required = false;
 
         if let TokenType::Operator(_) = tokens[index].deref() {
-            tokens.insert(index, Rc::new(TokenType::Number(0.0)));
+            tokens.insert(index, Rc::new(TokenType::Number(0.0, NumberType::Decimal)));
         }
 
         while index < tokens.len() {
