@@ -1,5 +1,5 @@
 /*
- * smartcalc v1.0.2
+ * smartcalc v1.0.5
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
@@ -9,7 +9,7 @@ use core::cell::RefCell;
 use alloc::string::ToString;
 use alloc::string::String;
 use alloc::sync::Arc;
-use chrono::{Datelike, Duration, Local, NaiveDate};
+use chrono::{Datelike, Duration, NaiveDate, Utc, TimeZone};
 use crate::app::Session;
 use crate::compiler::duration::DurationItem;
 use crate::config::SmartCalcConfig;
@@ -130,27 +130,30 @@ impl DataItem for DateItem {
             }
         };
         
-        let date_format = match self.0.year() == Local::now().date().year() {
+        let date_format = match self.0.year() == Utc::now().date().year() {
             true => format.date.get("current_year"),
             false => format.date.get("full_date")
         };
 
+        let tz_offset = chrono::FixedOffset::east(self.1.offset * 60);
+        let datetime = tz_offset.from_utc_date(&self.0);
+        
         match date_format {
             Some(data) => {
-                match get_month_info(config, &format.language, self.0.month() as u8) {
+                match get_month_info(config, &format.language, datetime.month() as u8) {
                     Some(month_info) => data.clone()
-                        .replace("{day}", &self.0.day().to_string())
-                        .replace("{month}", &self.0.month().to_string())
-                        .replace("{day_pad}", &left_padding(self.0.day().into(), 2))
-                        .replace("{month_pad}", &left_padding(self.0.month().into(), 2))
+                        .replace("{day}", &datetime.day().to_string())
+                        .replace("{month}", &datetime.month().to_string())
+                        .replace("{day_pad}", &left_padding(datetime.day().into(), 2))
+                        .replace("{month_pad}", &left_padding(datetime.month().into(), 2))
                         .replace("{month_long}", &uppercase_first_letter(&month_info.long))
                         .replace("{month_short}", &uppercase_first_letter(&month_info.short))
-                        .replace("{year}", &self.0.year().to_string())
+                        .replace("{year}", &datetime.year().to_string())
                         .replace("{timezone}", &self.1.name),
-                    None => self.0.to_string()
+                    None => datetime.to_string()
                 }
             },
-            None => self.0.to_string()
+            None => datetime.to_string()
         }
     }
     fn unary(&self, _: UnaryType) -> Arc<dyn DataItem> {
@@ -169,7 +172,7 @@ fn date_test() {
     let config = SmartCalcConfig::default();
     let session = RefCell::new(Session::default());
 
-    assert_eq!(DateItem(NaiveDate::from_ymd(2020, 1, 1), config.get_time_offset()).print(&config, &session), "1 Jan 2020 UTC".to_string());
+    assert_eq!(DateItem(NaiveDate::from_ymd(2020, 1, 1), config.get_time_offset()).print(&config, &session), "1 Jan 2020".to_string());
 
     let left = DateItem(NaiveDate::from_ymd(2020, 1, 1), config.get_time_offset());
     let right = DateItem(NaiveDate::from_ymd(2020, 1, 1), config.get_time_offset());
@@ -182,5 +185,5 @@ fn date_test() {
     let result = left.calculate(&config, true, &right, OperationType::Add);
     
     assert!(result.is_some());
-    assert_eq!(result.unwrap().print(&config, &session), "21 Jan 2020 UTC".to_string());
+    assert_eq!(result.unwrap().print(&config, &session), "21 Jan 2020".to_string());
 }
\ No newline at end of file
