@@ -1,5 +1,5 @@
 /*
- * smartcalc v1.0.2
+ * smartcalc v1.0.5
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
@@ -9,7 +9,7 @@ use core::cell::RefCell;
 use alloc::string::ToString;
 use alloc::string::String;
 use alloc::sync::Arc;
-use chrono::{Duration, NaiveDateTime, Local};
+use chrono::{Duration, NaiveDateTime, Utc};
 use crate::app::Session;
 use crate::config::SmartCalcConfig;
 use crate::constants::DurationFormatType;
@@ -96,7 +96,7 @@ impl DurationItem {
 
         seconds = duration_info;
         
-        let date = Local::now().naive_local().date();
+        let date = Utc::now().naive_local().date();
         let time = chrono::NaiveTime::from_hms(hours as u32, minutes as u32, seconds as u32);
         NaiveDateTime::new(date, time)
     }
