@@ -1,5 +1,5 @@
 /*
- * smartcalc v1.0.2
+ * smartcalc v1.0.5
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
@@ -17,15 +17,19 @@ pub fn number_regex_parser(config: &SmartCalcConfig, tokinizer: &mut Tokinizer,
         for capture in re.captures_iter(&tokinizer.data.to_owned()) {
             /* Check price value */
             let mut number = 0.0;
+            let mut number_type = NumberType::Decimal;
 
             if let Some(binary) = capture.name("BINARY") {
                 number = i64::from_str_radix(binary.as_str(), 2).unwrap() as f64;
+                number_type = NumberType::Binary;
             }
             else if let Some(hex) = capture.name("HEX") { 
                 number = i64::from_str_radix(hex.as_str(), 16).unwrap() as f64;
+                number_type = NumberType::Hexadecimal;
             }
-            else if let Some(hex) = capture.name("OCTAL") { 
-                number = i64::from_str_radix(hex.as_str(), 8).unwrap() as f64;
+            else if let Some(octal) = capture.name("OCTAL") { 
+                number = i64::from_str_radix(octal.as_str(), 8).unwrap() as f64;
+                number_type = NumberType::Octal;
             }
             else if let Some(decimal) = capture.name("DECIMAL") {
                 number = match decimal.as_str().replace(&config.thousand_separator[..], "").replace(&config.decimal_seperator[..], ".").parse::<f64>() {
@@ -48,7 +52,7 @@ pub fn number_regex_parser(config: &SmartCalcConfig, tokinizer: &mut Tokinizer,
                 };
             }
 
-            if tokinizer.add_token_location(capture.get(0).unwrap().start(), capture.get(0).unwrap().end(), Some(TokenType::Number(number)), capture.get(0).unwrap().as_str().to_string()) {
+            if tokinizer.add_token_location(capture.get(0).unwrap().start(), capture.get(0).unwrap().end(), Some(TokenType::Number(number, number_type)), capture.get(0).unwrap().as_str().to_string()) {
                 tokinizer.ui_tokens.add_from_regex_match(capture.get(0), UiTokenType::Number);
             }
         }
@@ -74,19 +78,19 @@ fn number_test_1() {
     assert_eq!(tokens.len(), 4);
     assert_eq!(tokens[0].start, 0);
     assert_eq!(tokens[0].end, 4);
-    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(1024.0)));
+    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(1024.0, NumberType::Decimal)));
     
     assert_eq!(tokens[1].start, 5);
     assert_eq!(tokens[1].end, 10);
-    assert_eq!(tokens[1].token_type.borrow().deref(), &Some(TokenType::Number(-1024.0)));
+    assert_eq!(tokens[1].token_type.borrow().deref(), &Some(TokenType::Number(-1024.0, NumberType::Decimal)));
     
     assert_eq!(tokens[2].start, 11);
     assert_eq!(tokens[2].end, 17);
-    assert_eq!(tokens[2].token_type.borrow().deref(), &Some(TokenType::Number(1024.1)));
+    assert_eq!(tokens[2].token_type.borrow().deref(), &Some(TokenType::Number(1024.1, NumberType::Decimal)));
     
     assert_eq!(tokens[3].start, 18);
     assert_eq!(tokens[3].end, 25);
-    assert_eq!(tokens[3].token_type.borrow().deref(), &Some(TokenType::Number(-1024.1)));
+    assert_eq!(tokens[3].token_type.borrow().deref(), &Some(TokenType::Number(-1024.1, NumberType::Decimal)));
 }
 
 #[cfg(test)]
@@ -107,27 +111,27 @@ fn number_test_2() {
     assert_eq!(tokens.len(), 6);
     assert_eq!(tokens[0].start, 0);
     assert_eq!(tokens[0].end, 5);
-    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(256.0)));
+    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(256.0, NumberType::Hexadecimal)));
     
     assert_eq!(tokens[1].start, 6);
     assert_eq!(tokens[1].end, 11);
-    assert_eq!(tokens[1].token_type.borrow().deref(), &Some(TokenType::Number(256.0)));
+    assert_eq!(tokens[1].token_type.borrow().deref(), &Some(TokenType::Number(256.0, NumberType::Hexadecimal)));
     
     assert_eq!(tokens[2].start, 12);
     assert_eq!(tokens[2].end, 15);
-    assert_eq!(tokens[2].token_type.borrow().deref(), &Some(TokenType::Number(1.0)));
+    assert_eq!(tokens[2].token_type.borrow().deref(), &Some(TokenType::Number(1.0, NumberType::Hexadecimal)));
     
     assert_eq!(tokens[3].start, 16);
     assert_eq!(tokens[3].end, 19);
-    assert_eq!(tokens[3].token_type.borrow().deref(), &Some(TokenType::Number(1.0)));
+    assert_eq!(tokens[3].token_type.borrow().deref(), &Some(TokenType::Number(1.0, NumberType::Hexadecimal)));
     
     assert_eq!(tokens[4].start, 20);
     assert_eq!(tokens[4].end, 23);
-    assert_eq!(tokens[4].token_type.borrow().deref(), &Some(TokenType::Number(0.0)));
+    assert_eq!(tokens[4].token_type.borrow().deref(), &Some(TokenType::Number(0.0, NumberType::Hexadecimal)));
     
     assert_eq!(tokens[5].start, 24);
     assert_eq!(tokens[5].end, 27);
-    assert_eq!(tokens[5].token_type.borrow().deref(), &Some(TokenType::Number(0.0)));
+    assert_eq!(tokens[5].token_type.borrow().deref(), &Some(TokenType::Number(0.0, NumberType::Hexadecimal)));
 }
 
 #[cfg(test)]
@@ -148,27 +152,27 @@ fn number_test_3() {
     assert_eq!(tokens.len(), 6);
     assert_eq!(tokens[0].start, 0);
     assert_eq!(tokens[0].end, 5);
-    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(4.0)));
+    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(4.0, NumberType::Binary)));
     
     assert_eq!(tokens[1].start, 6);
     assert_eq!(tokens[1].end, 11);
-    assert_eq!(tokens[1].token_type.borrow().deref(), &Some(TokenType::Number(4.0)));
+    assert_eq!(tokens[1].token_type.borrow().deref(), &Some(TokenType::Number(4.0, NumberType::Binary)));
     
     assert_eq!(tokens[2].start, 12);
     assert_eq!(tokens[2].end, 15);
-    assert_eq!(tokens[2].token_type.borrow().deref(), &Some(TokenType::Number(1.0)));
+    assert_eq!(tokens[2].token_type.borrow().deref(), &Some(TokenType::Number(1.0, NumberType::Binary)));
     
     assert_eq!(tokens[3].start, 16);
     assert_eq!(tokens[3].end, 19);
-    assert_eq!(tokens[3].token_type.borrow().deref(), &Some(TokenType::Number(1.0)));
+    assert_eq!(tokens[3].token_type.borrow().deref(), &Some(TokenType::Number(1.0, NumberType::Binary)));
     
     assert_eq!(tokens[4].start, 20);
     assert_eq!(tokens[4].end, 23);
-    assert_eq!(tokens[4].token_type.borrow().deref(), &Some(TokenType::Number(0.0)));
+    assert_eq!(tokens[4].token_type.borrow().deref(), &Some(TokenType::Number(0.0, NumberType::Binary)));
     
     assert_eq!(tokens[5].start, 24);
     assert_eq!(tokens[5].end, 27);
-    assert_eq!(tokens[5].token_type.borrow().deref(), &Some(TokenType::Number(0.0)));
+    assert_eq!(tokens[5].token_type.borrow().deref(), &Some(TokenType::Number(0.0, NumberType::Binary)));
 }
 
 
@@ -190,25 +194,25 @@ fn number_test_4() {
     assert_eq!(tokens.len(), 6);
     assert_eq!(tokens[0].start, 0);
     assert_eq!(tokens[0].end, 5);
-    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(64.0)));
+    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(64.0, NumberType::Octal)));
     
     assert_eq!(tokens[1].start, 6);
     assert_eq!(tokens[1].end, 11);
-    assert_eq!(tokens[1].token_type.borrow().deref(), &Some(TokenType::Number(64.0)));
+    assert_eq!(tokens[1].token_type.borrow().deref(), &Some(TokenType::Number(64.0, NumberType::Octal)));
     
     assert_eq!(tokens[2].start, 12);
     assert_eq!(tokens[2].end, 15);
-    assert_eq!(tokens[2].token_type.borrow().deref(), &Some(TokenType::Number(1.0)));
+    assert_eq!(tokens[2].token_type.borrow().deref(), &Some(TokenType::Number(1.0, NumberType::Octal)));
     
     assert_eq!(tokens[3].start, 16);
     assert_eq!(tokens[3].end, 19);
-    assert_eq!(tokens[3].token_type.borrow().deref(), &Some(TokenType::Number(1.0)));
+    assert_eq!(tokens[3].token_type.borrow().deref(), &Some(TokenType::Number(1.0, NumberType::Octal)));
     
     assert_eq!(tokens[4].start, 20);
     assert_eq!(tokens[4].end, 23);
-    assert_eq!(tokens[4].token_type.borrow().deref(), &Some(TokenType::Number(0.0)));
+    assert_eq!(tokens[4].token_type.borrow().deref(), &Some(TokenType::Number(0.0, NumberType::Octal)));
     
     assert_eq!(tokens[5].start, 24);
     assert_eq!(tokens[5].end, 27);
-    assert_eq!(tokens[5].token_type.borrow().deref(), &Some(TokenType::Number(0.0)));
+    assert_eq!(tokens[5].token_type.borrow().deref(), &Some(TokenType::Number(0.0, NumberType::Octal)));
 }
