@@ -1,5 +1,5 @@
 /*
- * smartcalc v1.0.2
+ * smartcalc v1.0.5
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
@@ -68,6 +68,7 @@ impl ToString for VariableInfo {
 #[derive(Debug)]
 pub enum FieldType {
     Text(String),
+    DateTime(String),
     Date(String),
     Time(String),
     Money(String),
@@ -89,6 +90,7 @@ impl FieldType {
         match self {
             FieldType::Text(_) => "TEXT".to_string(),
             FieldType::Date(_) => "DATE".to_string(),
+            FieldType::DateTime(_) => "DATE_TIME".to_string(),
             FieldType::Time(_) => "TIME".to_string(),
             FieldType::Money(_) => "MONEY".to_string(),
             FieldType::Percent(_) => "PERCENT".to_string(),
@@ -158,9 +160,18 @@ pub struct TimeOffset {
     pub offset: i32
 }
 
+#[derive(Debug, Copy, Clone, PartialEq)]
+pub enum NumberType {
+    Decimal,
+    Octal,
+    Hexadecimal,
+    Binary,
+    RAW
+}
+
 #[derive(Debug, Clone)]
 pub enum TokenType {
-    Number(f64),
+    Number(f64, NumberType),
     Text(String),
     Time(NaiveDateTime, TimeOffset),
     Date(NaiveDate, TimeOffset),
@@ -183,7 +194,7 @@ impl PartialEq for TokenType {
             (TokenType::Timezone(l_value, l_type),     TokenType::Timezone(r_value, r_type)) => *l_value == *r_value && *l_type == *r_type,
             (TokenType::Memory(l_value, l_type),     TokenType::Memory(r_value, r_type)) => *l_value == *r_value && *l_type == *r_type,
             (TokenType::Text(l_value),     TokenType::Text(r_value)) => *l_value == *r_value,
-            (TokenType::Number(l_value),   TokenType::Number(r_value)) => l_value == r_value,
+            (TokenType::Number(l_value, _),   TokenType::Number(r_value, _)) => l_value == r_value,
             (TokenType::Percent(l_value),  TokenType::Percent(r_value)) => l_value == r_value,
             (TokenType::Operator(l_value), TokenType::Operator(r_value)) => l_value == r_value,
             (TokenType::Variable(l_value), TokenType::Variable(r_value)) => l_value == r_value,
@@ -200,6 +211,7 @@ impl PartialEq for TokenType {
                     (FieldType::Number(l),  FieldType::Number(r)) => r == l,
                     (FieldType::Text(l),    FieldType::Text(r)) => r == l,
                     (FieldType::Date(l),    FieldType::Date(r)) => r == l,
+                    (FieldType::DateTime(l),    FieldType::DateTime(r)) => r == l,
                     (FieldType::Time(l),    FieldType::Time(r)) => r == l,
                     (FieldType::Money(l),   FieldType::Money(r)) => r == l,
                     (FieldType::Month(l),   FieldType::Month(r)) => r == l,
@@ -217,7 +229,7 @@ impl PartialEq for TokenType {
 impl ToString for TokenType {
     fn to_string(&self) -> String {
         match &self {
-            TokenType::Number(number) => number.to_string(),
+            TokenType::Number(number, _) => number.to_string(),
             TokenType::Text(text) => text.to_string(),
             TokenType::Time(time, tz) => {
                 let tz_offset = chrono::FixedOffset::east(tz.offset * 60);
@@ -251,7 +263,7 @@ impl ToString for TokenType {
 impl TokenType {
     pub fn type_name(&self) -> String {
         match self {
-            TokenType::Number(_) => "NUMBER".to_string(),
+            TokenType::Number(_, _) => "NUMBER".to_string(),
             TokenType::Text(_) => "TEXT".to_string(),
             TokenType::Time(_, _) => "TIME".to_string(),
             TokenType::Date(_, _) => "DATE".to_string(),
@@ -274,7 +286,7 @@ impl TokenType {
                 (TokenType::Text(l_value), SmartCalcAstType::Symbol(r_value)) => l_value.deref() == r_value,
                 (TokenType::Memory(l_value, l_type), SmartCalcAstType::Item(r_value)) => r_value.is_same(&(l_value.clone(), l_type.clone())),
                 (TokenType::Timezone(l_value, l_type), SmartCalcAstType::Item(r_value)) => r_value.is_same(&(l_value.clone(), l_type.clone())),
-                (TokenType::Number(l_value), SmartCalcAstType::Item(r_value)) => r_value.is_same(l_value),
+                (TokenType::Number(l_value, _), SmartCalcAstType::Item(r_value)) => r_value.is_same(l_value),
                 (TokenType::Percent(l_value), SmartCalcAstType::Item(r_value)) => r_value.is_same(l_value),
                 (TokenType::Duration(l_value), SmartCalcAstType::Item(r_value)) => r_value.is_same(l_value),
                 (TokenType::Time(l_value, l_tz), SmartCalcAstType::Item(r_value)) => r_value.is_same(&(l_value.clone(), l_tz.clone())),
@@ -291,6 +303,7 @@ impl TokenType {
                         (FieldType::Duration(_),   SmartCalcAstType::Item(item)) => item.type_name() == "DURATION",
                         (FieldType::Memory(_),   SmartCalcAstType::Item(item)) => item.type_name() == "MEMORY",
                         (FieldType::Timezone(_),   SmartCalcAstType::Item(item)) => item.type_name() == "TIMEZONE",
+                        (FieldType::DateTime(_),   SmartCalcAstType::Item(item)) => item.type_name() == "DATE_TIME",
                         (FieldType::Date(_),   SmartCalcAstType::Item(item)) => item.type_name() == "DATE",
                         (FieldType::TypeGroup(types, _), right_ast) => types.contains(&right_ast.type_name()),
                         (_, _) => false,
@@ -306,6 +319,7 @@ impl TokenType {
         match &token.token_type.borrow().deref() {
             Some(TokenType::Field(field)) =>  match field.deref() {
                 FieldType::Text(field_name)    => Some(field_name.to_string()),
+                FieldType::DateTime(field_name)    => Some(field_name.to_string()),
                 FieldType::Date(field_name)    => Some(field_name.to_string()),
                 FieldType::Time(field_name)    => Some(field_name.to_string()),
                 FieldType::Money(field_name)   => Some(field_name.to_string()),
@@ -448,7 +462,7 @@ impl core::cmp::PartialEq<TokenType> for TokenInfo {
         match &self.token_type.borrow().deref() {
             Some(l_token) => match (&l_token, &other) {
                 (TokenType::Text(l_value), TokenType::Text(r_value)) => l_value == r_value,
-                (TokenType::Number(l_value),   TokenType::Number(r_value)) => l_value == r_value,
+                (TokenType::Number(l_value, _),   TokenType::Number(r_value, _)) => l_value == r_value,
                 (TokenType::Percent(l_value),  TokenType::Percent(r_value)) => l_value == r_value,
                 (TokenType::Operator(l_value), TokenType::Operator(r_value)) => l_value == r_value,
                 (TokenType::Date(l_value, l_tz), TokenType::Date(r_value, r_tz)) => l_value == r_value && l_tz == r_tz,
@@ -463,9 +477,10 @@ impl core::cmp::PartialEq<TokenType> for TokenInfo {
                         (FieldType::Percent(_), TokenType::Percent(_)) => true,
                         (FieldType::Memory(_),  TokenType::Memory(_, _)) => true,
                         (FieldType::Timezone(_),  TokenType::Timezone(_, _)) => true,
-                        (FieldType::Number(_),  TokenType::Number(_)) => true,
+                        (FieldType::Number(_),  TokenType::Number(_, _)) => true,
                         (FieldType::Text(_),    TokenType::Text(_) ) => true,
                         (FieldType::Time(_),    TokenType::Time(_, _)) => true,
+                        (FieldType::DateTime(_),    TokenType::DateTime(_, _)) => true,
                         (FieldType::Date(_),    TokenType::Date(_, _)) => true,
                         (FieldType::Money(_),   TokenType::Money(_, _)) => true,
                         (FieldType::Month(_),   TokenType::Month(_)) => true,
@@ -480,9 +495,10 @@ impl core::cmp::PartialEq<TokenType> for TokenInfo {
                         (FieldType::Percent(_), TokenType::Percent(_)) => true,
                         (FieldType::Memory(_), TokenType::Memory(_, _)) => true,
                         (FieldType::Timezone(_), TokenType::Timezone(_, _)) => true,
-                        (FieldType::Number(_),  TokenType::Number(_)) => true,
+                        (FieldType::Number(_),  TokenType::Number(_, _)) => true,
                         (FieldType::Text(_),    TokenType::Text(_) ) => true,
                         (FieldType::Time(_),    TokenType::Time(_, _)) => true,
+                        (FieldType::DateTime(_),    TokenType::DateTime(_, _)) => true,
                         (FieldType::Date(_),    TokenType::Date(_, _)) => true,
                         (FieldType::Money(_),   TokenType::Money(_, _)) => true,
                         (FieldType::Duration(_),   TokenType::Duration(_)) => true,
@@ -508,7 +524,7 @@ impl PartialEq for TokenInfo {
         match (&self.token_type.borrow().deref(), &other.token_type.borrow().deref()) {
             (Some(l_token), Some(r_token)) => match (&l_token, &r_token) {
                 (TokenType::Text(l_value), TokenType::Text(r_value)) => l_value == r_value,
-                (TokenType::Number(l_value),   TokenType::Number(r_value)) => l_value == r_value,
+                (TokenType::Number(l_value, _),   TokenType::Number(r_value, _)) => l_value == r_value,
                 (TokenType::Percent(l_value),  TokenType::Percent(r_value)) => l_value == r_value,
                 (TokenType::Operator(l_value), TokenType::Operator(r_value)) => l_value == r_value,
                 (TokenType::Date(l_value, l_tz), TokenType::Date(r_value, r_tz)) => l_value == r_value && l_tz == r_tz,
@@ -522,10 +538,11 @@ impl PartialEq for TokenInfo {
                         (FieldType::Percent(_), TokenType::Percent(_)) => true,
                         (FieldType::Memory(_), TokenType::Memory(_, _)) => true,
                         (FieldType::Timezone(_), TokenType::Timezone(_, _)) => true,
-                        (FieldType::Number(_),  TokenType::Number(_)) => true,
+                        (FieldType::Number(_),  TokenType::Number(_, _)) => true,
                         (FieldType::Text(_),    TokenType::Text(_) ) => true,
                         (FieldType::Time(_),    TokenType::Time(_, _)) => true,
                         (FieldType::Date(_),    TokenType::Date(_, _)) => true,
+                        (FieldType::DateTime(_),    TokenType::DateTime(_, _)) => true,
                         (FieldType::Money(_),   TokenType::Money(_, _)) => true,
                         (FieldType::Duration(_), TokenType::Duration(_)) => true,
                         (FieldType::Month(_),   TokenType::Month(_)) => true,
@@ -539,10 +556,11 @@ impl PartialEq for TokenInfo {
                         (FieldType::Percent(_), TokenType::Percent(_)) => true,
                         (FieldType::Memory(_), TokenType::Memory(_, _)) => true,
                         (FieldType::Timezone(_), TokenType::Timezone(_, _)) => true,
-                        (FieldType::Number(_),  TokenType::Number(_)) => true,
+                        (FieldType::Number(_),  TokenType::Number(_, _)) => true,
                         (FieldType::Text(_),    TokenType::Text(_) ) => true,
                         (FieldType::Time(_),    TokenType::Time(_, _)) => true,
                         (FieldType::Date(_),    TokenType::Date(_, _)) => true,
+                        (FieldType::DateTime(_),    TokenType::DateTime(_, _)) => true,
                         (FieldType::Money(_),   TokenType::Money(_, _)) => true,
                         (FieldType::Month(_),   TokenType::Month(_)) => true,
                         (FieldType::Duration(_), TokenType::Duration(_)) => true,
@@ -637,21 +655,21 @@ impl SmartCalcAstType {
     pub fn type_name(&self) -> String {
         match self {
             SmartCalcAstType::None => "NONE".to_string(),
-            SmartCalcAstType::Item(_) => "ITEM".to_string(),
-            SmartCalcAstType::Field(_) => "FIELD".to_string(),
+            SmartCalcAstType::Item(item) => item.type_name().to_string(),
+            SmartCalcAstType::Field(field) => field.type_name(),
             SmartCalcAstType::Month(_) => "MONTH".to_string(),
             SmartCalcAstType::Binary {
                 left: _,
                 operator: _,
                 right: _
             } => "BINARY".to_string(),
-            SmartCalcAstType::PrefixUnary(_, _) => "PREFIX_UNARY".to_string(),
+            SmartCalcAstType::PrefixUnary(_, ast) => ast.type_name(),
             SmartCalcAstType::Assignment {
                 index: _,
                 expression: _
             } => "ASSIGNMENT".to_string(),
             SmartCalcAstType::Symbol(_) => "SYMBOL".to_string(),
-            SmartCalcAstType::Variable(_) => "VARIABLE".to_string()
+            SmartCalcAstType::Variable(variable) => variable.data.borrow().type_name()
         }
     }
 }
