@@ -1,5 +1,5 @@
 /*
- * smartcalc v1.0.2
+ * smartcalc v1.0.5
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
@@ -30,6 +30,8 @@ lazy_static! {
         m.insert("time_for_location".to_string(),  time_for_location as ExpressionFunc);
         m.insert("convert_timezone".to_string(),   convert_timezone as ExpressionFunc);
         m.insert("time_with_timezone".to_string(), time_with_timezone as ExpressionFunc);
+        m.insert("to_unixtime".to_string(),        to_unixtime as ExpressionFunc);
+        m.insert("from_unixtime".to_string(),      from_unixtime as ExpressionFunc);
         m.insert("small_date".to_string(),         small_date as ExpressionFunc);
         
         m.insert("convert_money".to_string(),      convert_money as ExpressionFunc);
