@@ -1,5 +1,5 @@
 /*
- * smartcalc v1.0.2
+ * smartcalc v1.0.5
  * Copyright (c) Erhan BARIS (Ruslan Ognyanov Asenov)
  * Licensed under the GNU General Public License v2.0.
  */
@@ -44,11 +44,11 @@ pub fn memory_convert(_: &SmartCalcConfig, _: &Tokinizer, fields: &BTreeMap<Stri
 #[test]
 fn number_on_1() {
     use core::ops::Deref;
-    use crate::tokinizer::test::execute;
+    use crate::{tokinizer::test::execute, types::NumberType};
     
     let tokens = execute("6% on 40".to_string());
     
-    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(42.4)));
+    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(42.4, NumberType::Decimal)));
 }
 
 
@@ -56,11 +56,11 @@ fn number_on_1() {
 #[test]
 fn number_of_1() {
     use core::ops::Deref;
-    use crate::tokinizer::test::execute;
+    use crate::{tokinizer::test::execute, types::NumberType};
     
     let tokens = execute("6% of 40".to_string());
 
-    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(2.4)));
+    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(2.4, NumberType::Decimal)));
 }
 
 
@@ -68,9 +68,9 @@ fn number_of_1() {
 #[test]
 fn number_off_1() {
     use core::ops::Deref;
-    use crate::tokinizer::test::execute;
+    use crate::{tokinizer::test::execute, types::NumberType};
     
     let tokens = execute("6% off 40".to_string());
 
-    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(37.6)));
+    assert_eq!(tokens[0].token_type.borrow().deref(), &Some(TokenType::Number(37.6, NumberType::Decimal)));
 }
